#' Get times
#'
#' Function to extract timings and assemble results in a dataframe
#'
#' @param simulate_results  results from `simulte()` function.
#'
#' @return Dataframe of 

get_times <- function(simulate_results) {
    
    sim <- simulate_results$sim
    
    for (s in 1:sim$control$nsims) {
        if (s == 1) {
            times <- sim$times[[paste("sim", s, sep = "")]]
            times <- times %>% mutate(s = s)
        } else {
            times <- times %>% bind_rows(sim$times[[paste("sim", s, sep = "")]] 
                                         %>% mutate(s = s))
        }
    }
    
    times <- times %>% mutate(infTime = ifelse(infTime < 0, -5, 
                                               infTime), expTime = ifelse(expTime < 0, -5, expTime)) %>% 
        mutate(incubation_period = infTime - expTime, illness_duration = recovTime - 
                   expTime, illness_duration_hosp = dischTime - expTime, 
               hosp_los = dischTime - hospTime, quarantine_delay = quarTime - 
                   infTime, survival_time = fatTime - infTime) %>% 
        select(s, incubation_period, quarantine_delay, illness_duration, 
               illness_duration_hosp, hosp_los, survival_time) %>% 
        pivot_longer(-s, names_to = "period_type", values_to = "duration") %>% 
        mutate(period_type = factor(period_type, levels = c("incubation_period", 
                                                            "quarantine_delay", "illness_duration", "illness_duration_hosp", 
                                                            "hosp_los", "survival_time"), labels = c("Incubation period", 
                                                                                                     "Delay entering isolation", "Illness duration", "Illness duration (hosp)", 
                                                                                                     "Hospital care required duration", "Survival time of case fatalities"), ordered = TRUE))
    return(times)
}


